@@ -188,8 +188,7 @@ estimate_boot_reps_for_target_cv <- function(svrepstat, target_cv = 0.05) {
   ) |> as.data.frame()
   
   result <- list(
-    'summary' = summary_df,
-    'function' = summary_fn
+    'summary' = summary_df
   )
   # Return the result
   class(result) <- union('sim_cv_curve', class(result))
@@ -307,11 +306,13 @@ plot.sim_cv_curve <- function(x, ...) {
 #' The column \code{STATISTIC} gives the name of the statistic.
 #' The column \code{SIMULATION_CV} gives the estimated simulation CV of the statistic.
 #' The column \code{N_REPLICATES} gives the number of bootstrap replicates.
+#' 
+#' This object has no plot method. To produce plots, use the 
+#' closely-related function \code{\link[svrep]{estimate_boot_reps_for_target_cv}}.
 #' @export
 #' @seealso Use \code{\link[svrep]{estimate_boot_reps_for_target_cv}} to help choose the number of bootstrap replicates.
 #' @examples
 #' \donttest{
-#' 
 #' set.seed(2022)
 #'
 #' # Create an example bootstrap survey design object ----
