@@ -177,6 +177,39 @@ test_that(
   }
 )
 
+# Test SDR method functionality ----
+
+test_that(
+  desc = "`as_sdr_design()` works for database-backed designs", {
+
+    suppressMessages({
+      suppressWarnings({
+        # Create bootstrap replicates for database-backed design
+        set.seed(2023)
+        db_sdr_result <- dbclus1 |>
+          as_sdr_design(
+            sort_variable = "dnum",
+            replicates = 16
+          )
+  
+        # Create replicates for design in local memory
+        set.seed(2023)
+        nondb_sdr_result <- dclus1 |>
+          as_sdr_design(
+            sort_variable = "dnum",
+            replicates = 16
+          )
+      })
+    })
+
+    # Compare estimates
+    expect_equal(
+      svytotal(x = ~ api00, db_sdr_result)    |> SE(),
+      svytotal(x = ~ api00, nondb_sdr_result) |> SE()
+    )
+    }
+)
+
 # Test weight redistribution functionality ----
 
 test_that(
